/* extension.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported init */

const { AccountsService, Clutter, Gio,
		GLib, GObject, Pango, Polkit, Shell, St }  = imports.gi;
const Util = imports.misc.util;
const EndSessionDialog = imports.ui.endSessionDialog;
const ExtensionUtils = imports.misc.extensionUtils;

class Extension {
	constructor() {
	}

	enable() {
		EndSessionDialog.EndSessionDialog.prototype._updateButtons = function() {
			let dialogContent = EndSessionDialog.DialogContent[this._type];
			let buttons = [{ action: this.cancel.bind(this),
							 label: _("Cancel"),
							 key: Clutter.KEY_Escape }];

			for (let i = 0; i < dialogContent.confirmButtons.length; i++) {
				let signal = dialogContent.confirmButtons[i].signal;
				let label = dialogContent.confirmButtons[i].label;
				buttons.push({
					action: () => {
						this.close(true);
						let signalId = this.connect('closed', () => {
							this.disconnect(signalId);
							this._confirm(signal);
						});
					},
					label,
				});
			}
			if (this._type != 0) {
				let settings = ExtensionUtils.getSettings('org.gnome.shell.extensions.net.bgreco.restartinto');
				let secondaryEntry = settings.get_string('entry');
				if (secondaryEntry) {
					buttons.splice(2, 0, {
						action: () => {
							this.close(true);
							Util.spawn(['systemctl', 'reboot', '--boot-loader-entry=' + secondaryEntry]);
						},
						label: settings.get_string('label')
					});
				}
			}
			this.setButtons(buttons);
		};
	}

	disable() {
	}
}

function init() {
	return new Extension();
}
